@@ -1,5 +1,5 @@
 from . import by as _by
-from parameters import parameters
+from .parameters import parameters
 import os
 
 class Tier(object):
